@@ -36,7 +36,7 @@ import remote
 import local
 
 
-VERSION = '0.4.0'
+VERSION = '0.4.1'
 
 
 def hook_setup(cmd):
@@ -48,24 +48,6 @@ def hook_destroy(cmd):
     if '-h' in cmd: return
     local.confirm('Please confirm destruction')
 
-def hook_push(cmd):
-    if '-h' in cmd or len(cmd) < 2:
-        return
-    if len(cmd) == 2:
-        cmd.append('.')
-    orig = dir = os.path.realpath(cmd[2])
-    while True:
-        if os.path.isdir(dir) and os.path.exists(os.path.join(dir, 'dotcloud.yml')):
-            if dir != orig:
-                utils.info('# Found dotcloud.yml: Using {0} as a base directory'.format(dir))
-            cmd[2] = dir
-            return
-        prev = dir
-        dir = os.path.realpath(os.path.join(dir, os.path.pardir))
-        if dir == prev:
-            local.confirm('Could not find dotcloud.yml file in {0} and parent directories. Proceed?'.format(orig))
-            break
-
 def hook___version(cmd):
     print 'DotCloud CLI version {0}'.format(VERSION)
     sys.exit(0)
@@ -146,7 +128,7 @@ def run_loop(cmd, state, interval, timeout=100):
             break
         if count > timeout:
             sys.stderr.write('\nTimed out\n')
-            break
+            sys.exit(1)
         if isinstance(state, dict) and 'active' in state:
             count = 0
         else:
