@@ -23,7 +23,7 @@ import subprocess
 
 import utils
 import config
-
+import local
 
 class Remote(object):
 
@@ -168,9 +168,25 @@ class Remote(object):
                 self.die('git')
 
     def upload(self, local_dir, destination, args):
+        if args.get('check'):
+            local_dir = self.check_pushdir(local_dir)
         self.info('# upload {0} {1}'.format(local_dir, destination))
         if os.path.isdir(os.path.join(local_dir, '.hg')):
             return self.hg(local_dir, destination, args.get('hg', {}))
         if os.path.isdir(os.path.join(local_dir, '.git')):
             return self.git(local_dir, destination, args.get('git', {}))
         return self.rsync(local_dir, destination, args.get('rsync', {}))
+
+    def check_pushdir(self, dir):
+        orig = dir = os.path.realpath(dir)
+        while True:
+            if os.path.isdir(dir) and os.path.exists(os.path.join(dir, 'dotcloud.yml')):
+                if dir != orig:
+                    utils.info('# Found dotcloud.yml: Using {0} as a base directory'.format(dir))
+                return dir
+            prev = dir
+            dir = os.path.realpath(os.path.join(dir, os.path.pardir))
+            if dir == prev:
+                local.confirm('Could not find dotcloud.yml file in {0} and parent directories. Proceed?'.format(orig))
+                break
+        return orig
